@@ -9,7 +9,6 @@ import cv2
 import numpy as np
 
 from ok import Logger
-from ok.alas.utils import cached_property
 from ok.capture.adb.deep import deep_get
 from ok.capture.adb.minitouch import insert_swipe
 from ok.capture.adb.nemu_utils import retry_sleep, RETRY_TRIES
@@ -192,7 +191,7 @@ def retry(func):
                     self.reconnect()
             # Unknown, probably a trucked image
             except Exception as e:
-                logger.exception(e)
+                logger.error("retry error", e)
 
                 def init():
                     pass
@@ -230,8 +229,7 @@ class NemuIpcImpl:
                 self.lib = ctypes.CDLL(ipc_dll)
                 break
             except OSError as e:
-                logger.error(e)
-                logger.error(f'ipc_dll={ipc_dll} exists, but cannot be loaded')
+                logger.error(f'ipc_dll={ipc_dll} exists, but cannot be loaded', e)
                 continue
         if self.lib is None:
             # not found
@@ -411,7 +409,7 @@ class NemuIpcImpl:
         if self.height == 0:
             self.get_resolution()
 
-        x, y = self.convert_xy(x, y)
+        # x, y = self.convert_xy(x, y)
 
         ret = self.run_func(
             self.lib.nemu_input_event_touch_down,
@@ -486,8 +484,7 @@ class NemuIpc:
                 display_id=0
             ).__enter__()
         except (NemuIpcIncompatible, NemuIpcError, JobTimeout) as e:
-            logger.error(e)
-            logger.error('Unable to initialize NemuIpc')
+            logger.error('Unable to initialize NemuIpc', e)
             raise Exception
 
     @staticmethod
