@@ -7,13 +7,13 @@ logger = Logger.get_logger(__name__)
 
 
 class OneTimeTaskTab(TaskTab):
-    def __init__(self):
+    def __init__(self, tasks):
         super().__init__()
-
-        for task in og.executor.onetime_tasks:
+        self.tasks = tasks
+        for task in tasks:
             task_card = TaskCard(task, True)
             self.add_widget(task_card)
         self.keep_info_when_done = True
 
     def in_current_list(self, task):
-        return task in og.executor.onetime_tasks
+        return task in self.tasks
